/**
 ****************************************************************************
 * @file         FileInfoDO.js
 * @brief        Declaration and Implementation of File info data objects
 *
 * Copyright 2011 by Samsung Electronics, Inc.,
 *
 * This software is the confidential and proprietary information
 * of Samsung Electronics, Inc. ("Confidential Information").  You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Samsung.
 *
 * @author       Subhash Chandra
 * @date         18/05/2011
 * Change History
 * Date              By                      Reason
 * 18/05/2011        Subhash Chandra         created
 ****************************************************************************/

var dataInfoArr = new Array();
var categoryDataInfo = new Array();

/**
 ****************************************************************************
 * @class       FileInfoDO
 * @brief       interface of the file info data objects class
 * @author      Sachin Sharma
 * @date        18/05/2011
 ****************************************************************************
 */
var FileInfoDO = new Class({
	filepath : null,
	thumbnailpath : null,
	title : null,
	date : null,
	duration : null,
	description : null,
	facebookflag : null,
	facebookVideoID : null,
	resolution : null,
	fileSize : null,
	filename : null,
	isVideo : null,
	duration : null,
	service : null,

	/**
	 *****************************************************************************
	 * @fn               initialize
	 * @brief            constructor of FileInfoDO class (filename,file path ,date etc.)
	 * @param[in]        filepath:-file path
	 * @param[in]        filename:-file name
	 * @param[in]        thumbnailpath:-thumbnail path
	 * @param[in]        title:-title of video
	 * @param[in]        date:-creation date
	 * @param[in]        duration:-total video duration
	 * @param[in]        description:-video description
	 * @param[in]        facebookflag:-video upload flag on facebook
	 * @param[in]        facebookdate:-video upload date on facebook
	 * @param[in]        isVideo:-flag to check whether file is Video or not
	 * @param[in]        facebookVideoID:-facebook upload video ID
	 * @return           none
	 *****************************************************************************
	 */
	initialize : function(filepath, filename, thumbnailpath, isVideo, date, service, resolution, fileSize, duration) {
		if(filepath != null)
			this.filepath = filepath;
		if(filename != null)
			this.filename = filename;
		if(thumbnailpath != null) {
			this.thumbnailpath = thumbnailpath;
		}
		if(isVideo != null) {
			var bVideo= new Boolean();
			if(isVideo==0 || isVideo==false)
			{
				bVideo = false;
			}
			else
			{
			  bVideo = true;
			}
			this.isVideo = bVideo;
		}
		if(date != null) {
			this.date = date;
		}
		if(service != null) {
			this.service = service;
		}
		if(resolution != null) {
			this.resolution = resolution;
		}
		if(fileSize != null) {
			this.fileSize = fileSize;
		}
		if(duration != null) {
			this.duration = duration;
		}
	}
});
USBFileInfo = new Class({
	filepath : null,
	filename : null,
	thumbnailpath : null,
	isVideo : null,
	initialize : function(filepath, filename, thumbnailpath, isVideo) {
		if(filepath != null) {
			this.filepath = filepath;
		}
		if(filename != null) {
			this.filename = filename;
		}
		if(thumbnailpath != null) {
			this.thumbnailpath = thumbnailpath;
		}
		if(isVideo != null) {
			var bVideo= new Boolean();
			if(isVideo==0 || isVideo==false)
			{
				bVideo = false;
			}
			else
			{
			  bVideo = true;
			}
			this.isVideo = bVideo;
		}
	}
});

var DataInfo = function(fileInfoDO, type) {
	this.fileArray = new Array();
	this.type = type;
	//alert("fileInfoDO*********&&&&&&&&&&&" +fileInfoDO.filename);
	this.fileArray[0] = fileInfoDO;
	//alert("fileArray********" +this.fileArray[0].filename);
};
var DataInnerInfo = function(fileT) {
	this.fileInfoArr = new Array();
	alert("fileT********" + fileT.filename);
	this.date = fileT.date;
	this.fileInfoArr[0] = fileT;
	alert("fileInfoArr********" + this.fileInfoArr[0].filename);
};
var groupDate = function() {
	var length = dataInfoArr.length;

}
var CategoryDataInfo = function(CatNum, categoryRow) {
	this.category = CatNum;
	//alert("*************Current Category Num************="+CatNum);
	this.categoryRow = categoryRow;
	//alert("*************Current Category Row************="+categoryRow);
};
var getTotalCategory = function() {
	var length = dataInfoArr.length;
	return length;
}
var FillData = function(fileDOArr, sortType) {
	var infoLen = 0;
	infoLen = dataInfoArr.length;
	var checkCondition = "";
	if(sortType == ENUM_SORT_TYPE.SORTBY_LATEST_DATE || sortType == ENUM_SORT_TYPE.SORTBY_EARLIEST_DATE) {
		checkCondition = formatDate(fileDOArr.date);
	} else if(sortType == ENUM_SORT_TYPE.SORTBY_TITLE) {
		checkCondition = fileDOArr.filename[0].toLowerCase();

		var chkKoreaChar = checkCondition.charCodeAt(0);
		if(chkKoreaChar >= 0xAC00 && chkKoreaChar <= 0xD7A3) {
			var font_first = new Array('ㄱ', 'ㄲ', 'ㄴ', 'ㄷ', 'ㄸ', 'ㄹ', 'ㅁ', 'ㅂ', 'ㅃ', 'ㅅ', 'ㅆ', 'ㅇ', 'ㅈ', 'ㅉ', 'ㅊ', 'ㅋ', 'ㅌ', 'ㅍ', 'ㅎ');
			var UniValue = chkKoreaChar - 0xAC00;
			var Jong = UniValue % 28;
			var Jung = ((UniValue - Jong) / 28) % 21;
			var Cho = parseInt(((UniValue - Jong) / 28) / 21);
			alert("Check condition for korean in sorting is : " + font_first[Cho]);
			checkCondition = font_first[Cho];
		}
	} else {
		checkCondition = fileDOArr.service;
	}
	if(infoLen == 0) {
		dataInfoArr[0] = new DataInfo(fileDOArr, checkCondition);
		return;
	} else {
		for( index = 0; index < infoLen; index++) {
			if(dataInfoArr[index].type == checkCondition) {
				dataInfoArr[index].fileArray.push(fileDOArr);
				break;
			}
		}
		if(index == infoLen) {
			dataInfoArr[index] = new DataInfo(fileDOArr, checkCondition);
		}
	}
}
var getFileInGrp = function(grpType) {
	var count = 0;
	var infoLen = 0;
	infoLen = dataInfoArr.length;
	logger.log("getFileInGrp**************");
	for(var index = 0; index < infoLen; index++) {// serach if messgae is for an existing user
		if(dataInfoArr[index].type == grpType) {
			return dataInfoArr[index].fileArray;
		}
	}
}
USBInfo = new Class({
	partitionKey : null,
	usbName : null,
	usbPath : null,
	usbTotalSpace : null,
	usbAvailSpace : null,
	usbFileSystem : null,

	initialize : function(partitionKey, usbName, usbPath, usbTotalSpace, usbAvailSpace, usbFileSystem) {
		if(partitionKey != null)
			this.partitionKey = partitionKey;
		if(usbName != null)
			this.usbName = usbName;
		if(usbPath != null)
			this.usbPath = usbPath;
		if(usbTotalSpace != null)
			this.usbTotalSpace = usbTotalSpace;
		if(usbAvailSpace != null)
			this.usbAvailSpace = usbAvailSpace;
		if(usbFileSystem != null)
			this.usbFileSystem = usbFileSystem;
	}
});

function setUSBInfo(parDiv, usbName, totalSize, availSize) {
	//alert("USb name for particular index********" +usbName);
	var totalSpace = totalSize;
	//alert("setUSBInfo Total space is *****:- "+totalSpace);
	var availSpace = availSize;
	//alert("setUSBInfo available space is *************:- "+availSpace);
	var freeSpace = totalSpace-availSpace;
	var widthfactor = (totalSpace - freeSpace) / totalSpace;
	var number = new Number(widthfactor);
	widthfactor = number.toFixed(2);
	//alert("setUSBInfo******width factor  is******" +widthfactor);
	if(totalSpace >= 1024) {
		totalSpace = (totalSpace / 1024);
		var num = new Number(totalSpace);
		totalSpace = num.toFixed(2);
		totalSpace = "/" + "  " + totalSpace + SID_GALLERY_USBSIZE_1;
		//alert("setUSBInfo total Space setDeviceListDetails  is " +totalSpace);
	} else {
		var num = new Number(totalSpace);
		totalSpace = num.toFixed(0);
		totalSpace = "/" + "  " + totalSpace + SID_GALLERY_USBSIZE_2;
		//alert("setUSBInfo total Space setDeviceListDetails  is " +totalSpace);
	}
	if(availSpace >= 1024) {
		availSpace = (availSpace / 1024);
		var num = new Number(availSpace);
		availSpace = num.toFixed(2);
		availSpace = availSpace + SID_GALLERY_USBSIZE_1 + "&nbsp";
		//availSpace = availSpace + SID_GALLERY_USBSIZE_1 + "  " + SID_GALLERY_USBSIZE_4 + "&nbsp";
		//alert("setUSBInfo total Space is setDeviceListDetails*****" +availSpace);
	} else {
		var num = new Number(availSpace);
		availSpace = num.toFixed(0);
		availSpace = availSpace + SID_GALLERY_USBSIZE_2 +"&nbsp";
		//availSpace = availSpace + SID_GALLERY_USBSIZE_2 + "  " + SID_GALLERY_USBSIZE_4 + "&nbsp";
		//alert("setUSBInfo total Space is setDeviceListDetails******** " +availSpace);
	}
	var filledWidth = widthfactor * 228;
	var num = new Number(filledWidth);
	filledWidth = num.toFixed(0);
	alert("*******====================Width to be Filled is*********** " + filledWidth);
	switch(parDiv) {
		case 0:
			alert("Gallery ALL*****SET****USBINFO");
			_$('galleryAll-usb-name').innerHTML = usbName;
			if(filledWidth > 8) {
				_$('galleryAll-usb-progressbar-centre').style.visibility = "visible";
				_$('galleryAll-usb-progressbar-left').style.visibility = "visible";
				_$('galleryAll-usb-progressbar-right').style.visibility = "visible";
				_$('galleryAll-usb-progressbar-centre').style.width = filledWidth - 8 + 'px';
				_$('galleryAll-usb-progressbar-right').style.left = filledWidth - 4 + 'px';
			} else {
				/*
				 if(filledWidth>=1)
				 {
				 _$('galleryAll-usb-progressbar-centre').style.visibility = "visible";
				 _$('galleryAll-usb-progressbar-left').style.visibility = "visible";
				 _$('galleryAll-usb-progressbar-right').style.visibility = "visible";
				 }
				 else
				 {
				 */
				_$('galleryAll-usb-progressbar-centre').style.visibility = "hidden";
				_$('galleryAll-usb-progressbar-left').style.visibility = "hidden";
				_$('galleryAll-usb-progressbar-right').style.visibility = "hidden";
				//}
			}
			_$('galleryAll-usb-availablesize').innerHTML = availSpace;
			_$('galleryAll-usb-totalsize').innerHTML = totalSpace;
			break;
		case 1:
			alert("MY VIDEO*****SET****USBINFO");
			_$('myvideo-usb-name').innerHTML = usbName;
			if(filledWidth > 8) {
				_$('myvideo-usb-progressbar-centre').style.visibility = "visible";
				_$('myvideo-usb-progressbar-left').style.visibility = "visible";
				_$('myvideo-usb-progressbar-right').style.visibility = "visible";
				_$('myvideo-usb-progressbar-centre').style.width = filledWidth - 8 + 'px';
				_$('myvideo-usb-progressbar-right').style.left = filledWidth - 4 + 'px';
			} else {
				/*
				 if(filledWidth>=1)
				 {
				 _$('myvideo-usb-progressbar-centre').style.visibility = "visible";
				 _$('myvideo-usb-progressbar-left').style.visibility = "visible";
				 _$('myvideo-usb-progressbar-right').style.visibility = "visible";
				 }
				 else
				 {
				 */
				_$('myvideo-usb-progressbar-centre').style.visibility = "hidden";
				_$('myvideo-usb-progressbar-left').style.visibility = "hidden";
				_$('myvideo-usb-progressbar-right').style.visibility = "hidden";
				//}
			}
			_$('myvideo-usb-availablesize').innerHTML = availSpace;
			_$('myvideo-usb-totalsize').innerHTML = totalSpace;
			break;
		case 2:
			alert("MY PHOTO*****SET****USBINFO");
			_$('myphoto-usb-name').innerHTML = usbName;
			if(filledWidth > 8) {
				_$('myphoto-usb-progressbar-centre').style.visibility = "visible";
				_$('myphoto-usb-progressbar-left').style.visibility = "visible";
				_$('myphoto-usb-progressbar-right').style.visibility = "visible";
				_$('myphoto-usb-progressbar-centre').style.width = filledWidth - 8 + 'px';
				_$('myphoto-usb-progressbar-right').style.left = filledWidth - 4 + 'px';
			} else {
				/*
				 if(filledWidth>=1)
				 {
				 _$('myphoto-usb-progressbar-centre').style.visibility = "visible";
				 _$('myphoto-usb-progressbar-left').style.visibility = "visible";
				 _$('myphoto-usb-progressbar-right').style.visibility = "visible";
				 }
				 else
				 {
				 */
				_$('myphoto-usb-progressbar-centre').style.visibility = "hidden";
				_$('myphoto-usb-progressbar-left').style.visibility = "hidden";
				_$('myphoto-usb-progressbar-right').style.visibility = "hidden";
				//}
			}
			_$('myphoto-usb-availablesize').innerHTML = availSpace;
			_$('myphoto-usb-totalsize').innerHTML = totalSpace;
			break;
	}
}


GetImgSuffixPath = function(){

	counterNum++;
	
	if(counterNum > 999){
		counterNum = 0;
	}
	
	return "?" + counterNum;
}

replaceWhiteSpace = function(str){
	
	var returnStr =str.replace(/ /gi, "&nbsp");
	alert("replaceWhiteSpace   ::"+returnStr);
	return returnStr;
}

changeWhiteSpace = function(str){
	
	var returnStr =str.replace(/ /gi, "\\ ");
	alert("changeWhiteSpace   ::"+returnStr);
	return returnStr;
}
