/**
****************************************************************************
* @file         Sorting.js
* @brief        Implementation of Sorting Class(sorting of video's)
*
* Copyright 2011 by Samsung Electronics, Inc.,
* 
* This software is the confidential and proprietary information
* of Samsung Electronics, Inc. ("Confidential Information").  You
* shall not disclose such Confidential Information and shall use
* it only in accordance with the terms of the license agreement
* you entered into with Samsung.
*
* @author       subhash.c
* @date         12/06/2011
* Change History        
* Date              By                      Reason
* 12/06/2011        Subhash Chandra         created
* 21/06/2011        Sutirtha Prakash        Modified  and generalized
****************************************************************************/

/**
****************************************************************************
* @class       Sorting
* @brief       interface of the Sorting class
* @author      subhash.c
* @date        12/06/2011
****************************************************************************
*/
var Sorting = new Class({

    Singleton : true,

    /**
*****************************************************************************
* @fn           initialize
* @brief        constructor of sorting class
* @param        none
* @return       none
*****************************************************************************
*/
    initialize: function()
    {
    },


    /*****************************************************************************
* @fn           sortFiles
* @brief        sort files according to date,name and video duration
* @param[in]    arr:-array of files
* @param[in]    str:-type of sort
* @return       array after sorted
*****************************************************************************
*/
    sortFiles:function(arr, sortType)
    {
        var tempArray = Array.clone(arr);
		alert("Sort type in sortFiles*******="+sortType);
        if(sortType==null)
        {
            return;
        }
		switch(sortType)
		{
			case 0:
				tempArray.sort(this.sortByLatestDate);
			break;
			case 1:
				tempArray.sort(this.sortByEarliestDate);
			break;
			case 2:
				tempArray.sort(this.sortByName);
			break;
			case 3:
				alert("***sorting By Service*****");
				tempArray.sort(this.sortByService);
				//return;
			break
		}
        return(tempArray);
    },
   
    /*****************************************************************************
* @fn           sortByName
* @brief        sort files by file name
* @param[in]    a:-first file
* @param[in]    b:-second file
* @return       0 or 1,-1
*****************************************************************************
*/
    sortByName:function(a,b)
    {
        var str1=a.filename.toLowerCase();
        var str2=b.filename.toLowerCase(); 
        if (str1 < str2) //sort string ascending
        {
            return -1 ;
        }
        if (str1 > str2)
        {
            return 1;
        }
        return 0; //default return value (no sorting)
    },



    sortByService:function(a,b)
    {
        var str1=a.service.toLowerCase();
        var str2=b.service.toLowerCase(); 
        if (str1 < str2) //sort string ascending
        {
            return -1 ;
        }
        if (str1 > str2)
        {
            return 1;
        }
        return 0; //default return value (no sorting)
    },
	
    /*****************************************************************************
* @fn           sortByLatestDate
* @brief        sort files by file creation date
* @param[in]    a:-first file
* @param[in]    b:-second file
* @return       0 or 1,-1
*****************************************************************************
*/
    sortByLatestDate:function(a,b)
    {
        var dateA=new Date(a.date);
        var dateB=new Date(b.date);
        if (dateA < dateB) //sort string descending
        {
            return 1 ;
        }
        if (dateA > dateB)
        {
            return -1;
        }
        return 0; //default return value (no sorting)
    },


    sortByEarliestDate:function(a,b)
    {
        var dateA=new Date(a.date);
        var dateB=new Date(b.date);
        if (dateA < dateB) //sort string descending
        {
            return -1 ;
        }
        if (dateA > dateB)
        {
            return 1;
        }
        return 0; //default return value (no sorting)
    },
	

    /*****************************************************************************
* @fn           sortByDuration
* @brief        sort files by file duration
* @param[in]    a:-first file
* @param[in]    b:-second file
* @return       0 or 1 or -1
*****************************************************************************
*/
    sortByDuration:function(a,b)
    {
        var durA=a.duration.split(":");
        var durB=b.duration.split(":");

        var durationA=durA[0]*3600+durA[1]*60+durA[2];
        var durationB=durB[0]*3600+durB[1]*60+durB[2];
        if (durationB-durationA >0) //sort string descending
        {
            return 1 ;
        }
        if (durationB-durationA < 0)
        {
            return -1;
        }
        return 0;
         
    } 
});

if(!this.sorting) {
	this.sorting = new Sorting();
}


function formatDuration(ms) {
    function two(x) {
        return ((x>9)?"":"0")+x
    }
    //   function three(x) {return ((x>99)?"":"0")+((x>9)?"":"0")+x}
    var sec = Math.floor(ms/1000);
    ms = ms % 1000;
    var min = Math.floor(sec/60);
    sec = sec % 60;
    t = two(sec);
    var hr = Math.floor(min/60);
    min = min % 60;
    t = two(min) + ":" + t;
    //hr = hr % 60;
    t = two(hr) + ":" + t;
    return t ;
}


function formatDate(str) {
    var date = new Date(str);
    var year = date.getFullYear();
    var month = date.getMonth()+1;
    var dateToday = date.getDate(); 
	var nDate=null;
	if(IS_KO_LANG==true)
	{
		nDate =year+"/"+month+"/"+dateToday ;
	}
	else
	{
		nDate =dateToday+"/"+month+"/"+year ;    
	}
    
    return nDate;
}

function getDate(dateArr)
{
	alert("getDate****** called*****str="+dateArr[2]);
	var month = "";
	var monthNum =Number(dateArr[2]);
	alert("getDate****** Number*****str="+monthNum);	
	switch(monthNum)
	{
		case 1:
			month ="Jan";
		break;
		case 2:
			month ="Feb";
		break;
		case 3:
			month ="March";
		break;
		case 4:
			month ="Apr";
		break;
		case 5:
			month ="May";
		break;
		case 6:
			month ="Jun";
		break;
		case 7:
			month ="Jul";
		break;
		case 8:
			month ="Aug";
		break;
		case 9:
			month ="Sep";
		break;
		case 10:
			month ="Oct";
		break;
		case 11:
			month ="Nov";
		break;
		case 12:
			month ="Dec";
		break;			
	}
	alert("*****after getting****month="+month);
	var dateStr = month+" "+dateArr[3]+","+" "+dateArr[1]+" "+dateArr[4]+":"+dateArr[5]+":"+dateArr[6];
	alert("date String to get Date is *****"+dateStr);
    var date = new Date(dateStr);
	alert("after *******date******************="+date);
	return date;
}

function formatSize(filesize) {
	alert("Format fileSize called*****fileSize="+filesize);
	var fileSize =filesize;
	fileSize = Number(fileSize);
	if(fileSize>=1024)
	{
		fileSize = (fileSize/1024);
		var num = new Number(fileSize);
		fileSize = num.toFixed(1);
		if(fileSize>=1024)
		{
			alert("In Case of File Size ***in****GB");
			fileSize = (fileSize/1024);
			var num = new Number(fileSize);
			fileSize = num.toFixed(1);
			fileSize = fileSize+SID_GALLERY_USBSIZE_1 ;
		}
		else
		{
			fileSize = fileSize+SID_GALLERY_USBSIZE_2;
		}
	}
	else
	{
		var num = new Number(fileSize);
		fileSize = num.toFixed(0);
		fileSize = fileSize+"KB";
	}
	alert("File Size is******* " +fileSize);	
	return fileSize;
}
