/**
****************************************************************************
* @file         XmlWriter.js
* @brief        Implementation of Xml writer to write XML
*
* Copyright 2011 by Samsung Electronics, Inc.,
* 
* This software is the confidential and proprietary information
* of Samsung Electronics, Inc. ("Confidential Information").  You
* shall not disclose such Confidential Information and shall use
* it only in accordance with the terms of the license agreement
* you entered into with Samsung.
*
* @author       subhash.c
* @date         15/05/2011
* Change History        
* Date              By                      Reason
* 15/05/2011        Subhash Chandra         created
****************************************************************************/



/**
****************************************************************************
* @class       XmlWriter
* @brief       interface of the XML Writer class
* @author      subhash.c
* @date        01/05/2011
****************************************************************************
*/
var XmlWriter = new Class({

    XML:null,
    Nodes:null,
    State:null,

    /**
*****************************************************************************
* @fn           initialize
* @brief        constructor of XmlWriter class
* @param        none
* @return       none
*****************************************************************************
*/
    initialize: function()
    {
        this.XML=[];
        this.Nodes=[];
        this.State="";
    },

    /**
*****************************************************************************
* @fn               formatXML
* @brief            Format the given string to write in XML
* @param[in]        str:-input string
* @return           formated string
*****************************************************************************
*/
    formatXML: function(str)
    {
        if (str)
            return str.replace(/&/g, "&amp;").replace(/\"/g, "&quot;").replace(/</g, "&lt;").replace(/>/g, "&gt;");
        return ""
    },

    /**
*****************************************************************************
* @fn               beginNode
* @brief            Starting name of node(begin node in XML)
* @param[in]        name:-node name
* @return           none
*****************************************************************************
*/
    beginNode: function(name)
    {
        if (!name) return;
        if (this.State=="beg") this.XML.push(">");
        this.State="beg";
        this.Nodes.push(name);
        this.XML.push("<"+name);
    },

    /**
*****************************************************************************
* @fn               endNode
* @brief            end Node in XML
* @param[in]        none
* @return           none
*****************************************************************************
*/
    endNode:function()
    {
        if (this.State=="beg")
        {
            this.XML.push("/>");
            this.Nodes.pop();
        }
        else if (this.Nodes.length>0)
            this.XML.push("</"+this.Nodes.pop()+">");
        this.State="";
    },

    /**
*****************************************************************************
* @fn               attributes
* @brief            attributes of  XML
* @param[in]        name:-name
* @param[in]        value:-value
* @return           none
*****************************************************************************
*/
    attributes:function(name, value)
    {
        if (this.State!="beg" || !name) return;
        this.XML.push(" "+name+"=\""+this.formatXML(value)+"\"");
    },

    /**
*****************************************************************************
* @fn               writeString
* @brief            write string into node
* @param[in]        value:-string value
* @return           none
*****************************************************************************
*/
    writeString:function(value)
    {
        if (this.State=="beg") this.XML.push(">");
        this.XML.push(this.formatXML(value));
        this.State="";
    },

    /**
*****************************************************************************
* @fn               Node
* @brief            Add node
* @param[in]        name:-name of node
* @param[in]        value:-string value
* @return           none
*****************************************************************************
*/
    Node: function(name,value)
    {
        if (!name) return;
        if (this.State=="beg") this.XML.push(">");
        this.XML.push((value=="" || !value)?"<"+name+"/>":"<"+name+">"+this.formatXML(value)+"</"+name+">");
        this.State="";
    },

    /**
*****************************************************************************
* @fn               Close
* @brief            Close XML File
* @param[in]        none
* @return           none
*****************************************************************************
*/
    Close:function()
    {
        while (this.Nodes.length>0)
            this.endNode();
        this.State="closed";
    },

    /**
*****************************************************************************
* @fn               toString
* @brief            to string
* @param[in]        none
* @return           string
*****************************************************************************
*/
    toString: function()
    {
        return this.XML.join("");
    }
});

if(!this.xmlWriter) {
	this.xmlWriter = new XmlWriter();
}